#
# Copyright 2019 GridGain Systems, Inc. and Contributors.
#
# Licensed under the GridGain Community Edition License (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.gridgain.com/products/software/community-edition/gridgain-community-edition-license
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
"""
This module is a source of some basic information about the binary protocol.

Most importantly, it contains `Query` and `Response` base classes. They are
used internally by :mod:`pygridgain.api` module. They, in turn, based on
:mod:`pygridgain.datatypes` binary parser/generator classes.
"""

from .query import Query, ConfigQuery, query_perform
